@@ -8,17 +8,19 @@
 #ifndef RIME_STRING_TABLE_H_
 #define RIME_STRING_TABLE_H_
 
+#include <cstdint>
 #include <utility>
 #include <marisa.h>
+#include <rime_api.h>
 #include <rime/common.h>
 
 namespace rime {
 
-using StringId = marisa::UInt32;
+using StringId = std::uint32_t;
 
 const StringId kInvalidStringId = (StringId)(-1);
 
-class StringTable {
+class RIME_DLL StringTable {
  public:
   StringTable() = default;
   virtual ~StringTable() = default;
@@ -26,10 +28,8 @@ class StringTable {
 
   bool HasKey(const string& key);
   StringId Lookup(const string& key);
-  void CommonPrefixMatch(const string& query,
-                         vector<StringId>* result);
-  void Predict(const string& query,
-               vector<StringId>* result);
+  void CommonPrefixMatch(const string& query, vector<StringId>* result);
+  void Predict(const string& query, vector<StringId>* result);
   string GetString(StringId string_id);
 
   size_t NumKeys() const;
@@ -39,9 +39,10 @@ class StringTable {
   marisa::Trie trie_;
 };
 
-class StringTableBuilder: public StringTable {
+class RIME_DLL StringTableBuilder : public StringTable {
  public:
-  void Add(const string& key, double weight = 1.0,
+  void Add(const string& key,
+           double weight = 1.0,
            StringId* reference = nullptr);
   void Clear();
   void Build();
